summaryrefslogtreecommitdiff
path: root/fml/lib
diff options
context:
space:
mode:
authorfukachan <fukachan>2006-11-19 13:48:37 +0000
committerfukachan <fukachan>2006-11-19 13:48:37 +0000
commit51cf8d388d015e136acf13b83e9812bb1462e474 (patch)
tree4de7db8031e7913332f96e631de1ede6ab13250e /fml/lib
parent040c868148ae8a483b866bf6c1fb196760d76037 (diff)
downloadfml8-51cf8d388d015e136acf13b83e9812bb1462e474.tar.gz
fml8-51cf8d388d015e136acf13b83e9812bb1462e474.tar.bz2
fml8-51cf8d388d015e136acf13b83e9812bb1462e474.zip
fix comments
Diffstat (limited to 'fml/lib')
-rw-r--r--fml/lib/FML/User/DB.pm16
-rw-r--r--fml/lib/FML/User/Info.pm20
2 files changed, 20 insertions, 16 deletions
diff --git a/fml/lib/FML/User/DB.pm b/fml/lib/FML/User/DB.pm
index bb7bb807..3c648db3 100644
--- a/fml/lib/FML/User/DB.pm
+++ b/fml/lib/FML/User/DB.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: DB.pm,v 1.11 2006/02/22 12:18:52 fukachan Exp $
+# $FML: DB.pm,v 1.12 2006/07/09 12:11:13 fukachan Exp $
#
package FML::User::DB;
@@ -39,9 +39,11 @@ FML::User::DB - maintain user database with expiration.
=head1 DESCRIPTION
+This class maitains user database with expiration.
+
=head1 METHODS
-=head2 C<new()>
+=head2 new()
constructor.
@@ -50,7 +52,7 @@ constructor.
# Descriptions: constructor.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($dbargs)
-# Side Effects: create object
+# Side Effects: create db_dir if needed.
# Return Value: OBJ
sub new
{
@@ -84,7 +86,7 @@ same as set() above.
# Descriptions: add { $key => $value } to $primary_user_db_${class}_map.
# Arguments: OBJ($self) STR($class) STR($key) STR($value)
-# Side Effects: update database
+# Side Effects: update database.
# Return Value: none
sub set
{
@@ -116,8 +118,8 @@ sub set
# Descriptions: find the first matched entry { $key => $value }
# in $primary_user_db_${class}_map.
# Arguments: OBJ($self) STR($class) STR($key)
-# Side Effects: update database
-# Return Value: none
+# Side Effects: none
+# Return Value: STR
sub get
{
my ($self, $class, $key) = @_;
@@ -145,7 +147,7 @@ sub get
# Descriptions: add { $key => $value } to $primary_user_db_${class}_map.
# Arguments: OBJ($self) STR($class) STR($key) STR($value)
-# Side Effects: update database
+# Side Effects: update database.
# Return Value: none
sub add
{
diff --git a/fml/lib/FML/User/Info.pm b/fml/lib/FML/User/Info.pm
index 6bacc63d..019f5447 100644
--- a/fml/lib/FML/User/Info.pm
+++ b/fml/lib/FML/User/Info.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: Info.pm,v 1.7 2006/02/18 09:25:32 fukachan Exp $
+# $FML: Info.pm,v 1.8 2006/02/22 12:16:31 fukachan Exp $
#
package FML::User::Info;
@@ -26,6 +26,8 @@ FML::User::Info - maintain user information.
=head1 DESCRIPTION
+This class maintains user information.
+
=head1 METHODS
=head2 new()
@@ -104,7 +106,7 @@ get information from gecos database.
# Descriptions: update gecos database.
# Arguments: OBJ($self) STR($address) STR($gecos)
-# Side Effects: update gecos database
+# Side Effects: update gecos database.
# Return Value: none
sub set_gecos
{
@@ -114,10 +116,10 @@ sub set_gecos
}
# Descriptions: get gecos info from database.
# Arguments: OBJ($self) STR($address)
-# Side Effects: update gecos database
-# Return Value: none
+# Side Effects: none
+# Return Value: STR
sub get_gecos
{
my ($self, $address) = @_;
@@ -141,7 +143,7 @@ get information from subscribe_date database.
# Descriptions: update subscribe_date database.
# Arguments: OBJ($self) STR($address) STR($subscribe_date)
-# Side Effects: update subscribe_date database
+# Side Effects: update subscribe_date database.
# Return Value: none
sub set_subscribe_date
{
@@ -151,10 +153,10 @@ sub set_subscribe_date
}
# Descriptions: get info from subscribe_date database.
# Arguments: OBJ($self) STR($address)
-# Side Effects: update subscribe_date database
-# Return Value: none
+# Side Effects: none
+# Return Value: STR
sub get_subscribe_date
{
my ($self, $address) = @_;
@@ -114,10 +116,10 @@ sub set_gecos
}
-# Descriptions: get gecos info from database.
+# Descriptions: get gecos information from database.
# Arguments: OBJ($self) STR($address)
@@ -151,10 +153,10 @@ sub set_subscribe_date
}
-# Descriptions: get info from subscribe_date database.
+# Descriptions: get information from subscribe_date database.
# Arguments: OBJ($self) STR($address)